@@ -89,7 +89,7 @@ pub enum CliCommand {
         timeout: Duration,
         blockhash: Option<Hash>,
         print_timestamp: bool,
-        additional_fee: Option<u32>,
+        compute_unit_price: Option<u64>,
     },
     Rent {
         data_length: usize,
@@ -876,7 +876,7 @@ pub fn process_command(config: &CliConfig) -> ProcessResult {
             timeout,
             blockhash,
             print_timestamp,
-            additional_fee,
+            compute_unit_price,
         } => process_ping(
             &rpc_client,
             config,
@@ -885,7 +885,7 @@ pub fn process_command(config: &CliConfig) -> ProcessResult {
             timeout,
             blockhash,
             *print_timestamp,
-            additional_fee,
+            compute_unit_price,
         ),
         CliCommand::Rent {
             data_length,
